import requests
from bs4 import BeautifulSoup


def get_soup(link):

    try:

        link = link.replace('\n','').strip()
        headers = {'User-agent': 'Mozilla/5.0'}
        response = requests.get(link,headers=headers)

        if response.status_code == requests.codes.ok:
            page = response.content
            soup = BeautifulSoup(page, "lxml")

        else:
            soup = None
            print("Requests returned status_code: {0}. {1}".format(response.status_code,link))

        return soup

    except Exception as e:
        print(str(e))
        print(link)


def send_model_object(data):
    print(data)


from setuptools import find_packages,setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(name='briefed_people_utils',
    version='0.1.0',
    description='Tools to support collect and send publically available data to Briefed.',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='https://Briefed.eu',
    author='Marek Zaremba-Pike',
    author_email='marekzp@gmail.com',
    license='MIT',
    packages=find_packages(),
    install_requires=[
        'requests',
        'bs4',
        'lxml',
    ],
    classifiers=(
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ),
)